# -*- coding: utf-8 -*-
###############################################################################~!!~~!!!
#
# Copyright (c) 2010-2012, OPENTIA Group (<http://opentia.com>)
# The word "OPENTIA" is an European Community Trademark property of the Opentia Group
#
# @author: Opentia "Happy Hacking" Team
# @e-mail: consultoria@opentia·es
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################~!!~~!!!

from osv import fields, osv
from tools.translate import _

class wizard_location_algorithm(osv.osv_memory):
    _name = 'stock.wizard.location.algorithm'
    _inherit = 'stock.move'
    _columns = {
        'pallet_type':fields.selection([('EUR','EUR'),('USA','USA')], 'Pallet', required=True, help=''),
        'inlung_product_ids': fields.many2many('product.product', 'stock_wizard_location_algorithm_rel', 'wiz_id', 'prod_id', 'Product list'),
    }
    _defaults = {
        'pallet_type': lambda *a: 'EUR',        
    }

    def default_get(self, cr, uid, fields, context=None):
        result = super(wizard_location_algorithm, self).default_get(cr, uid, fields, context)
        inlung_id = self.pool.get('stock.location').search(cr, uid, [('name','=',u'Pulmón Entrada')])[0]
        result.update({'location_id': inlung_id })
        c = context.copy()
        c.update({'location': inlung_id})
        product_ids = self.pool.get('product.product').search(cr,uid, [('real_available_qty','>',0)], context={'location':inlung_id})
        inlung_product_ids=[]
        for product_obj in self.pool.get('product.product').browse(cr, uid, product_ids, context={'location':inlung_id}):
            if product_obj.real_available_qty > 0: inlung_product_ids.append(product_obj.id)
        result.update({'inlung_product_ids': inlung_product_ids})
        return result

    def wizard_confirm(self, cr, uid, ids, context=None):
        #wizard_data = self.browse(cr, uid, ids)[0]
        wizard_data = self.read(cr, uid, ids[0])
        result={}
        inlung_id = self.pool.get('stock.location').search(cr, uid, [('name','=',u'Pulmón Entrada')])[0]
        c = {'location':inlung_id}
        if wizard_data['prodlot_id'] != None: c.update({'prodlot_id': wizard_data['prodlot_id']})
        product_obj = self.pool.get('product.product').browse(cr, uid, wizard_data['product_id'], context=c)
        if wizard_data['product_qty']<= 0: raise osv.except_osv(_('Error!'),_('Wrong quantity!'))
        elif wizard_data['product_qty']>product_obj.real_available_qty: raise osv.except_osv(_('Error!'),_('There are not enough units!'))
        picking_id = self.pool.get('stock.location').inlung2stock(cr, uid, ids, context=wizard_data)
        result.update({
            'name': ('Albarán pendiente'), 'context': context, 
            'view_type': 'form', 'view_mode': 'tree,form',
            'res_model': 'stock.picking',
            'domain': "[('id','=', %s)]" % picking_id,
            'type': 'ir.actions.act_window', 
#            'type': 'ir.actions.act_window_close'
        })
        return result

    def onchange_lot_id(self, cr, uid, ids, prodlot_id=False, product_qty=False,
                        loc_id=False, product_id=False, uom_id=False, context=None):
        result = super(wizard_484,self).onchange_lot_id(cr, uid, ids, prodlot_id, product_qty, loc_id, product_id, uom_id, context)
        inlung_id = self.pool.get('stock.location').search(cr, uid,  [('name','=',u'Pulmón Entrada')])[0]
        if prodlot_id:
            lot_obj = self.pool.get('stock.production.lot').browse(cr, uid, prodlot_id, context=context)
            values = {}
            if product_qty>lot_obj.stock_available: values.update({'product_qty':lot_obj.stock_available})
            result.update({'value': values})
        return result

    def onchange_product_packaging(self, cr, uid, ids, product_packaging=False, context=None):
        result={}
        product_packaging_obj=self.pool.get('product.packaging').browse(cr,uid,product_packaging)
        if product_packaging_obj.ul.type == 'pallet' and product_packaging_obj.ul.name == 'USA':
            result.update({'pallet_type':'USA'})
        elif product_packaging_obj.ul.type == 'pallet' and product_packaging_obj.ul.name == 'EUR':
            result.update({'pallet_type':'EUR'})
        return {'value':result}

wizard_location_algorithm()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
